@@ -1,5 +1,5 @@
 package EC::About;
-my $RCSRevKey = '$Revision: 1.4 $';
+my $RCSRevKey = '$Revision: 1.5 $';
 $RCSRevKey =~ /Revision: (.*?) /;
 $VERSION=$1;
 
@@ -35,10 +35,10 @@ sub Populate {
 	   -text => "\nEC Email Client\n Version ".$args->{-version}."\n");
   $l -> grid( -column => 2, -row => 1, -pady => 5, -columnspan => 2);
   my $l2 = $w -> Component( Label => 'copyright',
-   -text => "Copyright \xa9 2001-2004\nRobert Allan Kiesling, " .
+   -text => "Copyright \xa9 2001-2004,\nRobert Kiesling, " .
    "rkies\@cpan.org.\n" .
-   "MS Windows Compatibility:\nRoland Bauer, roland.bauer\@fff.at.\n\n" .
-   "Please read the file \"Artistic\" for license terms.\n");
+   "MS Windows Compatibility by Roland Bauer\n\n" .
+   "Please read the file, \"Artistic,\" for license terms.\n");
   $l2 -> grid( -column => 1, -row => 2, -padx => 5, -pady => 5,
 	      -columnspan => 3);
   $b = $w->Button( -text => 'Dismiss', -command => sub{$w->WmDeleteWindow},
